@@ -27,12 +27,14 @@ class BalconyServiceSummarizer(BaseBalconyApp,
     def get_data(self, *args, **kwargs) -> dict:
         service=kwargs.get('service')
         balcony = BalconyAWS()
-        typer.echo(service)
         service_node = balcony.get_service(service)
-        resource_nodes = service_node.get_resource_nodes()
+        print(service_node)
+        services_resource_nodes = service_node.get_resource_nodes()
+        print(resource_nodes)
+
         read_only_function_count = 0
         resource_nodes = []
-        for rn in resource_nodes:
+        for rn in services_resource_nodes:
             operation_names = rn.get_operation_names() 
             resource_nodes.append({
                 'name': rn.name,
